import domtoimage from "dom-to-image";
import { EditorModule } from "..";
import { DesignComp } from "../../objects/DesignTemp/DesignComp";
import { createCompStyle } from "../../objects/DesignTemp/creates/createCompStyle";
import { Layout } from "../../typings";

export const helpers = EditorModule.helper({
  designToNaturalSize(value: number) {
    return parseFloat((value / 100).toFixed(2)) + "rem";
  },
  findComp(compId: string) {
    const { compMap } = this.store.designData;
    const comp = compMap[compId];
    if (comp) return comp;
  },
  findParentComp(compId: string): DesignComp | undefined {
    const comp = this.helper.findComp(compId);
    if (comp) return this.helper.findComp(comp.pid);
  },
  findRootComp(): DesignComp | undefined {
    return this.store.designData.compMap["root"];
  },
  getCompTrees(compId: string) {
    const comps: DesignComp[] = [];
    const getParentComp = (compId: string) => {
      const comp = this.helper.findComp(compId);
      if (comp) {
        comps.unshift(comp);
        getParentComp(comp.pid);
      }
    };
    getParentComp(compId);
    return comps;
  },
  createStyle(layout: Partial<Layout>) {
    return createCompStyle(this, layout);
  },
  isCustomChildComp(comp: DesignComp): boolean {
    const parentComp = this.helper.findParentComp(comp.id);
    if (!parentComp) return false;
    const i =
      parentComp.children.default?.findIndex((d) => d === comp.id) ?? -1;
    return i >= 0;
  },
  // async screenshot() {
  //   // 解决html2canvas不支持object-fit的问题
  //   // https://github.com/niklasvh/html2canvas/issues/1064
  //   const dom = document.querySelector(".page-editing-content") as HTMLElement;
  //   const canvas = await html2canvas(dom, {
  //     useCORS: true,
  //   });
  //   dom.appendChild(canvas);
  //   return new Promise<Blob>((resolve, reject) => {
  //     canvas.toBlob((blob) => {
  //       if (blob) {
  //         resolve(blob);
  //       } else {
  //         reject("截屏失败");
  //       }
  //     });
  //   });
  // },
  async screenshot() {
    const dom = document.querySelector(".page-editing-content")?.parentElement as HTMLElement;
    const result = domtoimage.toBlob(dom);
    // result.then((blob) => {
    //   const img = document.createElement("img");
    //   img.src = URL.createObjectURL(blob);
    //   dom.appendChild(img);
    // });
    return result;
  },
});
