import { cloneDeep, isEmpty } from "lodash";
import { nanoid } from "nanoid";
import { Background, ICompKeys, Layout } from "../../typings";
import { mapValuesDeep } from "@/utils";

export class DesignComp {
  declare pid: string; // pid 作为前端临时数据，不存储到服务器，在初始化时关联
  declare $el: HTMLElement; // $el 映射dom
  id = nanoid();
  compKey: ICompKeys = "Text";
  value: any = undefined;
  layout: Layout = {};
  background: Background = {};
  children: Record<string, any> & { default?: string[] } = {};

  constructor(data?: Partial<DesignComp>) {
    if (!data) return;
    if (data instanceof DesignComp) return data;
    const fromData = Object.fromEntries(
      Object.entries(data).filter(
        ([, value]) => value !== null && value !== undefined
      )
    );
    Object.assign(this, cloneDeep(fromData));
  }

  getChildIds() {
    return mapValuesDeep(
      this.children,
      (v) => typeof v === "string",
      (v: string) => v
    );
  }

  get isPostioned() {
    return this.layout.position === "absolute";
  }
  get isTransformed() {
    return !isEmpty(this.layout.transform);
  }
  get isFullWidth() {
    const w = this.layout.size?.[0];
    return !w || w === 750;
  }
}
