import { useResource } from "@/modules/resource";
import { Button, Empty } from "ant-design-vue";
import { queenApi, useModal } from "queenjs";
import { defineComponent, reactive } from "vue";
import { useRoute } from "vue-router";
import OutputTemplateItem from "./OutputTemplateItem";

export default defineComponent({
  setup() {
    const resource = useResource();
    const modal = useModal();
    const route = useRoute();

    const state = reactive({
      images: [] as { id: string; qos: 1 }[],
      videos: [] as { id: string; qos: 1 }[],
    }) as any;

    const submit = async () => {
      if (state.images.length == 0 && state.videos.length == 0) {
        queenApi.messageError("请选择至少一个模板");
        return;
      }
      const isOk = await resource.actions.submitRender(
        route.params.id as string,
        state.images,
        state.videos
      );
      if (isOk) {
        modal.submit(true);
      }
    };

    return () => {
      const { sourceDetail } = resource.store;
      const isEmpty =
        sourceDetail.images?.length == 0 && sourceDetail.videos?.length == 0;

      return (
        <div>
          {isEmpty && <Empty description="暂无数据" />}
          <div class="grid grid-cols-4 gap-10px">
            {sourceDetail.images.map((record: any) => (
              <OutputTemplateItem
                record={record}
                active={!!state.images.find((v: any) => v.id == record.id)}
                onChange={(qos) => {
                  const selected = state.images.find(
                    (v: any) => v.id == record.id
                  );
                  selected.qos = qos;
                }}
                onSelect={() => {
                  const selected = !!state.images.find(
                    (v: any) => v.id == record.id
                  );
                  if (selected) {
                    const index = state.images.findIndex(
                      (d: any) => d.id == record.id
                    );
                    state.images.splice(index);
                    return;
                  }
                  state.images.push({ id: record.id, qos: 1 });
                }}
              />
            ))}
          </div>

          <div class="text-right mt-10px">
            <Button onClick={modal.cancel}>取消</Button>
            <Button type="primary" class="ml-20px" onClick={submit}>
              确定
            </Button>
          </div>
        </div>
      );
    };
  },
});
